Modified: db/derby/code/branches/10.6/java/build/org/apache/derbyBuild/ReportParser.java
URL: http://svn.apache.org/viewvc/db/derby/code/branches/10.6/java/build/org/apache/derbyBuild/ReportParser.java?rev=997028&r1=997027&r2=997028&view=diff
==============================================================================
--- db/derby/code/branches/10.6/releaseSummary.xml (original)
+++ db/derby/code/branches/10.6/releaseSummary.xml Tue Sep 14 18:15:29 2010
@@ -27,42 +27,51 @@ with real information.
<summary>
<!--
+ Release identifier.
+
+ E.g.: 10.3.0.3
+-->
+<releaseID>10.6.2.0</releaseID>
+
+<!--
Identifier of previous release. The release notes describe the
delta between releaseID and previousReleaseID.
E.g.: 10.2.1.7
-->
-<previousReleaseID>10.5.3.0</previousReleaseID>
+<previousReleaseID>10.6.1.0</previousReleaseID>
<!--
- Identifier(s) of previously released versions. Any issue that was fixed in
- any of these versions will be excluded from the fixed bugs list, and the
- release notes list.
-
- E.g.: 10.3.1.4 and 10.3.2.1
-
+ Information on the system used to build the release.
-->
-<excludeReleaseID>10.3.3.0</excludeReleaseID>
-<excludeReleaseID>10.4.1.3</excludeReleaseID>
-<excludeReleaseID>10.4.2.0</excludeReleaseID>
-<excludeReleaseID>10.5.1.1</excludeReleaseID>
-<excludeReleaseID>10.5.2.0</excludeReleaseID>
-<excludeReleaseID>10.5.3.0</excludeReleaseID>
<buildInfo>
+ <!-- Name of the branch. E.g.: 10.3 -->
+ <branch>10.6</branch>
+
<!-- Machine environment. E.g.: Cygwin on Microsoft Windows XP Professional Version
2002 Service Pack 2. -->
- <machine>Mac OS X 10.5.8.</machine>
+ <machine>Git(Msysgit) on Microsoft Windows 7 Ultimate 2009 64 bits</machine>
<!-- Ant version. E.g.: Apache Ant version 1.6.5 compiled on June 2 2005. -->
- <antVersion>Apache Ant version 1.7.1 compiled on June 27 2008.</antVersion>
+ <antVersion>Apache Ant version 1.7.1 compiled on June 27 2008</antVersion>
<!-- Output of "java -version" run from your jdk1.4 installation. E.g.: Java(TM) 2
Runtime Environment, Standard Edition (build 1.4.2_12-b03). -->
- <jdk1.4>Java(TM) 2 Runtime Environment, Standard Edition (build 1.4.2_22-b02-329).</jdk1.4>
+ <jdk1.4>java version "1.4.2_19"
+ Java(TM) 2 Runtime Environment, Standard Edition (build 1.4.2_19-b04)
+ Java HotSpot(TM) Client VM (build 1.4.2_19-b04, mixed mode)</jdk1.4>
+
+ <!-- Output of "java -version" run from your Java 6 installation. E.g.: Java(TM) 2 Runtime
Environment, Standard Edition (build 1.6.0-b105). -->
+ <java6>java version "1.6.0_13"
+ Java(TM) SE Runtime Environment (build 1.6.0_13-b03)
+ Java HotSpot(TM) Client VM (build 11.3-b02, mixed mode)</java6>
- <!-- Output of "java -version" run from your Java 6 installation. E.g.: Java(TM) 2
Runtime Environment, Standard Edition (build 1.6.0-b105). -->
- <java6>Java(TM) SE Runtime Environment (build 1.6.0_17-b04-248-9M3125).</java6>
+ <!--
+ Say here whether you used osgi.jar to build org.apache.derby.osgi.EmbeddedActivator.
+ E.g.: The osgi.jar was used to build org.apache.derby.osgi.EmbeddedActivator.
+ -->
+ <osgi>NO</osgi>
<!--
Say which compilers you used.
@@ -71,18 +80,22 @@ with real information.
The 1.4.2_12-b03 javac was used to compile all classes
except for the JDBC4 drivers. The JDBC4 driver classes were compiled using the
1.6.0-b105 javac.
-->
- <compilers>The 1.6.0_17-b04-248-9M3125 javac was used to compile all classes.</compilers>
+ <compilers>Sun 1.6.0_13_b03</compilers>
<!--
Say here whether you built the J2ME support and, if so, which
tookit you used.
E.g.: J2ME support was built using java.sun.com/j2me (j2me_cdc_fp-1_0_2).
-->
- <jsr169>J2ME support was built using libraries from phoneME Advanced Milestone Release
2.</jsr169>
</buildInfo>
-<overview>
+<!--
+ Here include a freeform section, describing the release. In this
+ section, all instances of the special tags <releaseID/> and
+ <previousReleaseID/> will be replaced with the values specified above.
+
+ E.g.:
<p>
Derby is a pure Java relational database engine using standard SQL and
@@ -100,52 +113,39 @@ Derby functionality includes:
<li>Command line tools: ij (SQL scripting), dblook (schema dump) and sysinfo (system
info)</li>
</ul>
-</overview>
+-->
-<newFeatures>
+<overview>
+<p>
+Derby is a pure Java relational database engine using standard SQL and
+JDBC as its APIs.
+</p>
<p>
-This is a feature release. The following new features were added:
+Derby functionality includes:
</p>
<ul>
-
-<li><b>Sequence Generators</b> - Named generators for allocating successive,
evenly spaced numbers. See feature T176 of the SQL Standard.</li>
-
-<li><b>User-defined types</b> - Named types bound to serializable Java
objects.</li>
-
-<li><b>Restricted table functions</b> - Limits on the columns and rows
returned by table functions.</li>
-
-<li><b>XPLAIN statistics collection</b> - Query plan statistics stored
in tables for later analysis.</li>
-
-<li><b>GROUP BY ROLLUP</b> - A subset of the SQL Standard ROLLUP functionality
on the GROUP BY clause. See feature T431 of the SQL Standard.</li>
-
-<li><b>CROSS JOIN</b> - CROSS JOIN syntax. See feature F401-04 of the SQL
Standard.</li>
-
-<li><b>Named columns join</b> - USING clauses in joins.</li>
-
-<li><b>SHOW FUNCTIONS</b> - IJ command that lists stored functions.</li>
-
-<li><b>In-memory back end enhancements</b> - Numerous improvements, including
the ability to delete in-memory databases.</li>
-
-<li><b>ORDER BY in subqueries</b> - Syntax for explicitly ordering rows
returned by subqueries. See features F851, F852, and F855 of the SQL Standard.</li>
-
-<li><b>OFFSET, FETCH FIRST/NEXT in subqueries</b> - Generalized syntax
for retrieving row subsets. See features F856, F857, F858, F859, F861, F862, F863, and F864
of the SQL Standard.</li>
-
-<li><b>NATURAL JOIN</b> - Support for NATURAL JOIN. See feature T431 of
the SQL Standard.</li>
-
-<li><b>Qualified identifers in ij</b> - Ability to reference cursors and
prepared statements in other connections.</li>
-
-<li><b>Configurable hash algorithm</b> - Ability to customize the hash
algorithm used by BUILTIN authentication.</li>
-
-<li><b>Context-sniffing scripts</b> - Ability of shipped scripts to locate
Derby jars when DERBY_HOME isn't set.</li>
-
-<li><b>Case-insensitive strings</b> - Ability to ignore case in string
comparisons and sorts.</li>
-
+<li>Embedded engine with JDBC drivers</li>
+<li>Network Server</li>
+<li>Network client JDBC drivers</li>
+<li>Command line tools: ij (SQL scripting), dblook (schema dump) and sysinfo (sy
+stem info)</li>
</ul>
+</overview>
+<!--
+ Here describe the new features of this release. E.g.:
+
+<p>
+This is a bug-fix release. No new features were added.
+</p>
+
+-->
+
+<newFeatures>
+This is a bug fix release which also provides localizations of new 10.6 messages. No new
features were added. This release addresses a data corruption issue. <a class="external"
href="http://issues.apache.org/jira/browse/DERBY-4677"><strong >DERBY-4677</strong></a>.
See release note for unique index corruption detection and repair.
</newFeatures>
</summary>
-
Modified: db/derby/code/branches/10.6/tools/ant/properties/release.properties
URL: http://svn.apache.org/viewvc/db/derby/code/branches/10.6/tools/ant/properties/release.properties?rev=997028&r1=997027&r2=997028&view=diff
==============================================================================
--- db/derby/code/branches/10.6/tools/ant/properties/release.properties (original)
+++ db/derby/code/branches/10.6/tools/ant/properties/release.properties Tue Sep 14 18:15:29
2010
@@ -1,6 +1,6 @@
#Tue Apr 27 10:56:20 PDT 2010
major=10
-maint=1000001
+maint=2000000
drdamaint=0
minor=6
eversion=10.6
Modified: db/derby/code/branches/10.6/tools/release/templates/releaseSummaryTemplate.xml
URL: http://svn.apache.org/viewvc/db/derby/code/branches/10.6/tools/release/templates/releaseSummaryTemplate.xml?rev=997028&r1=997027&r2=997028&view=diff
==============================================================================
--- db/derby/code/branches/10.6/tools/release/templates/releaseSummaryTemplate.xml (original)
+++ db/derby/code/branches/10.6/tools/release/templates/releaseSummaryTemplate.xml Tue Sep
14 18:15:29 2010
@@ -83,7 +83,6 @@ with real information.
tookit you used.
E.g.: J2ME support was built using java.sun.com/j2me (j2me_cdc_fp-1_0_2).
-->
- <jsr169>???</jsr169>
</buildInfo>
|
--- db/derby/code/branches/10.6/java/build/org/apache/derbyBuild/ReportParser.java (original)
+++ db/derby/code/branches/10.6/java/build/org/apache/derbyBuild/ReportParser.java Tue Sep
14 18:15:29 2010
@@ -76,7 +76,7 @@ public abstract class ReportParser
*/
public static ReportParser makeReportParser()
{
- return new April_2010();
+ return new September_2010();
}
/////////////////////////////////////////////////////////////////////////
@@ -164,7 +164,7 @@ public abstract class ReportParser
* <li>Fix Version/s</li>
* </ul>
*/
- public static final class April_2010 extends ReportParser
+ public static class April_2010 extends ReportParser
{
public TagReader parseNextIssue( TagReader masterReport ) throws Exception
{
@@ -216,9 +216,12 @@ public abstract class ReportParser
/**
* <p>
* The attachment ids don't turn up in the html reports produced by the Apache
* JIRA site. So, lamely, we hardcode attachment ids here. For this ReportParser,
* we hardcode the attachment ids of the 10.6.1 release notes.
* </p>
*/
public long getReleaseNoteAttachmentID( TagReader tr ) throws Exception
@@ -244,4 +247,24 @@ public abstract class ReportParser
}
}
+ /*
+ * For release 10.6.2.0, this class is introduce to generate the release
+ * note attachment id.
+ */
+ public static final class September_2010 extends April_2010 {
+ public long getReleaseNoteAttachmentID(TagReader tr) throws Exception {
+ tr.reset();
+
+ long result = NO_RELEASE_NOTE;
+ String key = parseKey(tr);
+
+ if (key.equals("4677")) {
+ result = 12454149L;
+ } else if (key.equals("2925")) {
+ result = 12379029L;
+ }
+
+ return result;
+ }
+ }
}
Modified: db/derby/code/branches/10.6/releaseSummary.xml
URL: http://svn.apache.org/viewvc/db/derby/code/branches/10.6/releaseSummary.xml?rev=997028&r1=997027&r2=997028&view=diff
@@ -216,9 +216,12 @@ public abstract class ReportParser
/**
* <p>
- * The attachment ids don't turn up in the html reports produced by the Apache
- * JIRA site. So, lamely, we hardcode attachment ids here. For this ReportParser,
- * we hardcode the attachment ids of the 10.6.1 release notes.
+ * The attachment ids don't turn up in the html reports produced by the
+ * Apache JIRA site. So, lamely, we hardcode attachment ids here. For
+ * this ReportParser, we hardcode the attachment ids of the 10.6.1
+ * release notes. If one produce similar report as .xml format instead
+ * of .html for fixedBugsList, one can grep for releaseNote.html to get
+ * the attachemtn ids easier
* </p>
*/
==============================================================================